<?php
/**
 * Main class
 *
 * @package WordPress
 */

/**
 * Declare class `Chirpyweb_Init.
 */
class Chirpyweb_Init {

	/**
	 * Setting options
	 *
	 * @var array $options got global options
	 */
	private $options = array();

	/**
	 * Calling class construct.
	 */
	public function __construct() {
		$this->options_pre = 'cw_options_';
		$this->options_key = 'cw-settings';
		add_action( 'wp_ajax_error_alert', 'chirpyweb_error_alert' );
		add_action( 'admin_init', array( $this, 'chirpyweb_submit_data' ) );
	}

	/**
	 * Get all pre options.
	 */
	public function get_options_pre() {
		return $this->options_pre;
	}

	/**
	 * Get all plugin options.
	 *
	 * @param string $key key.
	 * @param bool   $fetch featch Default false.
	 *
	 * @return string
	 */
	public function chirpyweb_get_option( $key, $fetch = false ) {
		if ( false === $fetch ) {
			$transient_key  = $this->options_pre . $key;
			$transient_body = $this->chirpyweb_transient_get( $transient_key );
			if ( false !== $transient_body ) {
				$option = $transient_body;
			} else {
				$option        = get_option( $key );
				$transient_key = $this->options_pre . $key;
				$this->chirpyweb_transient_set( $transient_key, $option );
			}
		} else {
			$option = get_option( $key );
		}
		return $option;
	}

	/**
	 * Update plugin options.
	 *
	 * @param string $key key.
	 * @param string $option option.
	 * @param bool   $cache cache Default true.
	 *
	 * @return string
	 */
	public function chirpyweb_update_option( $key, $option, $cache = true ) {
		$resp = update_option( $key, $option );
		if ( false !== $resp && true === $cache ) {
			$transient_key = $this->options_pre . $key;
			$this->chirpyweb_transient_set( $transient_key, $option );
		}
		return $resp;
	}

	/**
	 * Add Plugin options.
	 *
	 * @param string $key key.
	 * @param array  $option option.
	 * @param bool   $cache cache Default true.
	 *
	 * @return string
	 */
	public function chirpyweb_add_option( $key, $option, $cache = true ) {
		$resp = add_option( $key, $option );
		if ( $resp && true === $cache ) {
			$transient_key = $this->options_pre . $key;
			$this->chirpyweb_transient_set( $transient_key, $option );
		}
		return $resp;
	}

	/**
	 * Get Remote Url.
	 *
	 * @param string $url URL.
	 *
	 * @return array
	 */
	public static function chirpyweb_wp_remote_get( $url ) {
		$response = wp_safe_remote_get( $url );
		return $response;
	}

	/**
	 * Empty Configuration.
	 */
	public function chirpyweb_empty_config() {
		$cw_op          = array();
		$cw_op['url']   = '';
		$cw_op['uid']   = '';
		$cw_op['pid']   = '';
		$cw_op['cdn']   = '';
		$cw_op['sw']    = '';
		$cw_op['gcm']   = '';
		$cw_op['token'] = '';
		return $cw_op;
	}

	/**
	 * Verify the Key based on response
	 *
	 * @param string $key key.
	 * @return array
	 */
	public function chirpyweb_request( $key ) {
		$key            = sanitize_text_field( $key );
		$transient_key  = 'cw_config_' . $key;
		$transient_body = $this->chirpyweb_transient_get( $transient_key );
		if ( false !== $transient_body ) { // if cached.
			$response = $transient_body;
		} else {
			$options  = array(
				'timeout' => 30,
				'body'    => $key,
			);
			$response = wp_safe_remote_post(
				CHIRPY_WP_API . 'wp/code-snippet/',
				array(
					'body' => array(
						'website_key' => $key,
					),
				)
			);
			if ( 201 === wp_remote_retrieve_response_code( $response ) ) {
				$this->chirpyweb_transient_set( $transient_key, $response, 60 * 60 );
			}
		}
		$response_code = wp_remote_retrieve_response_code( $response );
		if ( 201 !== $response_code ) {
			self::chirpyweb_add_action( 'admin_notices', 'chirpyweb_error_token' );
		}
		if ( is_array( $response ) ) {
			$header = $response['headers'];
			$body   = $response['body'];
		}
			return $body;
	}

	/**
	 * Genrate sw-js file
	 *
	 * @param array $key key.
	 * @return string
	 */
	public function chirpyweb_sw_request( $key ) {
		$key            = sanitize_text_field( $key );
		$transient_key  = 'cw_config_' . $key;
		$transient_body = $this->chirpyweb_transient_get( $transient_key );
		$options        = array(
			'timeout' => 30,
			'body'    => $key,
		);
		$response       = wp_safe_remote_post(
			CHIRPY_WP_API . 'wp/service-worker/',
			array(
				'body' => array(
					'website_key' => $key,
				),
			)
		);
		$response_code  = wp_remote_retrieve_response_code( $response );
		if ( 201 !== $response_code ) {
			self::chirpyweb_add_action( 'admin_notices', 'chirpyweb_error_token' );
		}
		if ( is_array( $response ) ) {
			$header = $response['headers'];
			$body   = $response['body'];
		}
		return $body;
	}

	/**
	 * Transition Function
	 *
	 * @param string $key key.
	 * @return string
	 */
	public function chirpyweb_transient_get( $key ) {
		$response = get_transient( $key );
		return $response;
	}

	/**
	 * Transition Fubction
	 *
	 * @param string $key key.
	 *
	 * @param string $value value.
	 *
	 * @param string $exp_time exp_time.
	 * @return string
	 */
	public function chirpyweb_transient_set( $key, $value, $exp_time = 43200 ) {
		$response = set_transient( $key, $value, $exp_time );
		return $response;
	}

	/**
	 * Delete Transition
	 *
	 * @param array $key key.
	 * @return string
	 */
	public function chirpyweb_transient_del( $key ) {
		$response = delete_transient( $key );
		return $response;
	}

	/**
	 * Invalid Token
	 */
	public static function invalid_token() {
		add_settings_error( 'chirpyweb-notice', esc_html__( 'invalid', 'chirpyweb' ), esc_html__( "Reach out to ChirpyWeb's chat support or email at mailto:support@chirpyweb.com for assistance." ), 'error' );
		settings_errors( 'chirpyweb-notice' );
	}

	/**
	 * Empty Token
	 */
	public static function empty_token() {
		add_settings_error( 'chirpyweb-notice', esc_html__( 'empty', 'chirpyweb' ), esc_html__( 'ID cannot be empty. Submit your  ID to activate web push. Contact ChirpyWeb for any queries.' ), 'error' );
		settings_errors( 'chirpyweb-notice' );
	}

	/**
	 * Success message oF tokan
	 */
	public static function chirpyweb_notice_messages() {
		add_settings_error( 'chirpyweb-notice', esc_html__( 'api-updated', 'chirpyweb' ), esc_html__( 'ChirpyWeb push has been successfully activated on your WordPress site.' ), 'updated' );
		settings_errors( 'chirpyweb-notice' );
	}

	/**
	 * Success message oF tokan
	 *
	 * @param array $handle handle.
	 *
	 * @param array $func_name func_name.
	 *
	 * @param array $static static.
	 */
	public static function chirpyweb_add_action( $handle, $func_name, $static = true ) {
		if ( true === $static ) {
			$func_name = __CLASS__ . '::' . $func_name;
		}
		add_action( $handle, $func_name );
	}

	/**
	 * Error message oF invalid tokan
	 */
	public static function chirpyweb_error_token() {
		add_settings_error( 'chirpyweb-notice', esc_html__( 'invalid', 'chirpyweb' ), esc_html__( 'Invalid Website Key, Please re-verify your Website Key.' ), 'error' );
	}

	/**
	 * Error alert.
	 */
	public function chirpyweb_error_alert() {
		$action = filter_input( INPUT_POST, 'action' );
		if ( 'error_alert' !== $action ) {
			echo false;
			wp_die();
		}
		$msg                = filter_input( INPUT_POST, 'message' );
		$endpoint           = CHIRPY_WP_API . '?ref=wp&act=error_alert&chirpywebversion=' . CHIRPYWEBVERSION;
		$email              = get_bloginfo( 'admin_email' );
		$user               = get_user_by( 'email', $email )->data;
		$user['user_email'] = $email;
		$user_info          = wp_json_encode( $user );
		$wp_site_url        = esc_url( get_site_url() );
		$endpoint           = add_query_arg(
			array(
				'email'       => rawurlencode( sanitize_email( $email ) ),
				'url'         => rawurlencode( $wp_site_url ),
				'userdetails' => rawurlencode( $user_info ),
				'message'     => $msg,
			),
			CHIRPY_WP_API
		);
		$status             = self::chirpyweb_wp_remote_get( $endpoint );
		$response           = array(
			'status'          => 'logged',
			'WordPress Email' => $email,
			'WordPress Site'  => $wp_site_url,
			'UserDetails'     => $user,
		);
		echo wp_json_encode( $status );
		wp_die();
	}

	/**
	 * Validate & submit form data.
	 */
	public function chirpyweb_submit_data() {
		$cw          = new Chirpyweb_Init();
		$tokensubmit = filter_input( INPUT_POST, 'tokensubmit' );
		if ( isset( $tokensubmit ) && sanitize_text_field( $tokensubmit ) ) {
			$err   = 0;
			$cw_op = array();
			$token = filter_input( INPUT_POST, 'token' );
			if ( empty( $token ) || '' === sanitize_text_field( $token ) ) {
				$err   = 1;
				$cw_op = $cw->chirpyweb_empty_config();
				$cw->chirpyweb_update_option( 'cw-settings', $cw_op );
				self::chirpyweb_add_action( 'admin_notices', 'empty_token' );
			}
			if ( 0 === $err ) {
				$get_json1 = $cw->chirpyweb_sw_request( sanitize_text_field( $token ) );
				$get_user1 = json_decode( $get_json1, true );
				$get_json  = $cw->chirpyweb_request( sanitize_text_field( $token ) );
				$get_user  = json_decode( $get_json, true );
				if ( isset( $get_user['errors'] ) || isset( $get_user['error'] ) ) {
					$err       = 1;
					$cw_op     = $cw->chirpyweb_empty_config();
					$code      = '';
					$file_name = ABSPATH . 'sw-cw.js';
					if (file_exists( $file_name )) {
					unlink( $file_name );
					}
					self::chirpyweb_add_action( 'admin_notices', 'invalid_token' );
					$cw->chirpyweb_update_option( 'cw-settings', $cw_op );
					$cw->chirpyweb_update_option( 'cw-script', $code );
					$file_name_main   = plugin_dir_path( __FILE__ ) . '../templates/header_script.php';
					$file_exists_main = file_exists( $file_name_main );
					if ( $file_exists_main ) {
						unlink( $file_name_main );
					}
				} else {
					$code        = $get_user['code'];
					$code1       = $get_user1['code'];
					$file_name   = ABSPATH . 'sw-cw.js';
					$file_exists = file_exists( $file_name );
					if ( ! $file_exists ) {
						$create_file = touch( $file_name );
						if ( $create_file ) {
							file_put_contents( $file_name, $code1, FILE_APPEND); // phpcs:ignore
						}
					}
					else {
					    file_put_contents( $file_name, $code1); // phpcs:ignore
					}
					$cw_op['token'] = sanitize_text_field( $token );
					$cw->chirpyweb_update_option( 'cw-settings', $cw_op );
					$cw->chirpyweb_update_option( 'cw-script', $code );
					self::chirpyweb_add_action( 'admin_notices', 'chirpyweb_notice_messages' );
					$file_name_main   = plugin_dir_path( __FILE__ ) . '../templates/header_script.php';
					$file_exists_main = file_exists( $file_name_main );
					if ( ! $file_exists_main ) {
						$create_file_main = touch( $file_name_main );
						if ( $create_file_main ) {
							file_put_contents( $file_name_main, $code, FILE_APPEND | LOCK_EX ); // phpcs:ignore
						}
					}
					else {
					    file_put_contents( $file_name_main, $code); // phpcs:ignore
					}
				}
			}
		}
	}
}
$cw = new Chirpyweb_Init();
